#' Title
#'
#' @param degree.perct.list
#' @param alpha.val.list
#'
#' @return
#' @export
#'
#' @examples
#' run.poster()
#' run.poster(degree.threshold = c(.8, 0.25, .5, .75, .90), alpha = seq(1, .1, -.05), subset = c(Inf, 1000, 100), target.vars = c(33, 10), add.age.at.diag = c(FALSE, TRUE), calc.c.index = FALSE)

run.poster <- function(degree.threshold = c(0.8), alpha = c(1), subset = c(Inf), target.vars = c(33),
                       add.age.at.diag = c(FALSE), calc.c.index = TRUE) {
  require(futile.logger)
  require(digest)

  my.params.template <- list(  alpha = 1,
                               subset = Inf,
                               seed = 2017,
                               mc.cores = 14,
                               degree.min.threshold = 0,
                               force.recalc = FALSE,
                               degree.perct = .80,
                               folds = 1,
                               target.vars = 33,
                               cache.data.md5 = '26a945665bcb1ab1db5a37b0447f3417',
                               add.age.at.diag = TRUE)

  for (subset.val in subset) {
    for (degree.val in degree.threshold) {
      mclapply(alpha, function(alpha.val) {
        for (target.vars.val in target.vars) {
          for (add.age.at.diag.val in add.age.at.diag){
            my.params <- my.params.template

            my.params$subset          <- subset.val
            my.params$degree.perct    <- degree.val
            my.params$alpha           <- alpha.val
            my.params$target.vars     <- target.vars.val
            my.params$add.age.at.diag <- add.age.at.diag.val
            my.params$calc.c.index    <- calc.c.index

            intermediate.dir <- sprintf('vignettes/temp/poster-%s', digest(my.params))
            out.dir <- sprintf('vignettes/out-poster-%s', digest(my.params))

            file.name <- sprintf('poster-alpha_%.3f-subset_%.0f-seed_%d-degree_%.2f-target_%d-add_age_%s.html',
                                 my.params$alpha,
                                 my.params$subset,
                                 my.params$seed,
                                 my.params$degree.perct,
                                 my.params$target.vars,
                                 my.params$add.age.at.diag)


            if (!file.exists(file.name)) {
              flog.info('Saving to %s', file.name)
              rmarkdown::render(file.path('vignettes', 'poster.Rmd'),
                                intermediates_dir = intermediate.dir,
                                params = my.params,
                                output_dir = out.dir,
                                output_file = file.name,
                                clean = TRUE)
            }
          }
        }
      }, mc.cores = 8, mc.allow.recursive = FALSE)
    }
  }
}

